@@ -305,7 +305,7 @@ enmtools.glm <- function(species, env, f = NULL, test.prop = 0, eval = TRUE, nba
 
       env.training.plot <- ggplot(rts.env.training, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
         geom_histogram(binwidth = 0.05) +
-        geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
+        geom_vline(xintercept = env.model.evaluation@auc, linetype = "longdash") +
         xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
         ggtitle(paste("Model performance in environment space on training data")) +
         theme(plot.title = element_text(hjust = 0.5))
@@ -314,14 +314,14 @@ enmtools.glm <- function(species, env, f = NULL, test.prop = 0, eval = TRUE, nba
       if(test.prop > 0){
         test.plot <- ggplot(rts.geog.test, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
           geom_histogram(binwidth = 0.05) +
-          geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
+          geom_vline(xintercept = test.evaluation@auc, linetype = "longdash") +
           xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
           ggtitle(paste("Model performance in geographic space on test data")) +
           theme(plot.title = element_text(hjust = 0.5))
 
         env.test.plot <- ggplot(rts.env.test, aes(x = .data$AUC, fill = "density", alpha = 0.5)) +
           geom_histogram(binwidth = 0.05) +
-          geom_vline(xintercept = model.evaluation@auc, linetype = "longdash") +
+          geom_vline(xintercept = env.test.evaluation@auc, linetype = "longdash") +
           xlim(-0.05,1.05) + guides(fill = "none", alpha = "none") + xlab("AUC") +
           ggtitle(paste("Model performance in environment space on test data")) +
           theme(plot.title = element_text(hjust = 0.5))
