@@ -1,4 +1,4 @@
-#' Takes two emtools.species objects with range rasters, calculates overlap between them as in Fitzpatrick and Turelli 2006
+#' Takes two emtools.species objects with range rasters, calculates overlap between them as in Fitzpatrick and Turelli 2006.  This metric divides the area of overlap between two species ranges by the smaller of the two areas of the species' individual ranges.  It therefore ranges from 0 (no overlap) to 1 (ranges are the same or the smaller species' range is contained entirely within the larger).
 #'
 #' @param x An enmtools.species object containing a range raster
 #' @param y An enmtools.species object containing a range raster
@@ -6,8 +6,6 @@
 #' @return A numeric value measuring range overlap.
 #'
 #' @examples
-#' data(iberolacerta.clade)
-#' data(euro.worldclim)
 #' cyreni <- iberolacerta.clade$species$cyreni
 #' monticola <- iberolacerta.clade$species$monticola
 #' cyreni$range <- background.raster.buffer(cyreni$presence.points, 100000, euro.worldclim)
@@ -16,16 +14,16 @@
 
 geog.range.overlap <- function(x, y){
 
-  if(!inherits(x$range, c("raster", "RasterLayer"))){
+  if(!inherits(x$range, c("SpatRaster"))){
     stop(paste("Species", x$species.name, "does not have a range raster!"))
   }
 
-  if(!inherits(y$range, c("raster", "RasterLayer"))){
+  if(!inherits(y$range, c("SpatRaster"))){
     stop(paste("Species", y$species.name, "does not have a range raster!"))
   }
 
-  overlap.cells <- sum(getValues(x$range * y$range) == 1, na.rm = TRUE)
-  min.cells <- min(sum(getValues(x$range) == 1, na.rm = TRUE), sum(getValues(y$range) == 1, na.rm = TRUE))
+  overlap.cells <- sum(terra::values(x$range * y$range) == 1, na.rm = TRUE)
+  min.cells <- min(sum(terra::values(x$range) == 1, na.rm = TRUE), sum(terra::values(y$range) == 1, na.rm = TRUE))
   return(overlap.cells/min.cells)
 
 }
